@@ -123,6 +123,7 @@ const char *vaConfigAttribTypeStr(VAConfigAttribType configAttribType)
     TOSTR(VAConfigAttribCustomRoundingControl);
     TOSTR(VAConfigAttribQPBlockSize);
     TOSTR(VAConfigAttribStats);
+    TOSTR(VAConfigAttribMaxFrameSize);
     case VAConfigAttribTypeMax: break;
     }
     return "<unknown config attribute type>";
@@ -171,9 +172,50 @@ const char *vaBufferTypeStr(VABufferType bufferType)
     TOSTR(VAStatsMVPredictorBufferType);
     TOSTR(VAEncFEICTBCmdBufferType);
     TOSTR(VAEncFEICURecordBufferType);
+    TOSTR(VASubsetsParameterBufferType);
     case VABufferTypeMax: break;
     }
     return "<unknown buffer type>";
 }
 
+const char *vaStatusStr(VAStatus status)
+{
+    switch(status){
+        TOSTR(VA_STATUS_SUCCESS);
+        TOSTR(VA_STATUS_ERROR_OPERATION_FAILED);
+        TOSTR(VA_STATUS_ERROR_ALLOCATION_FAILED);
+        TOSTR(VA_STATUS_ERROR_INVALID_DISPLAY);
+        TOSTR(VA_STATUS_ERROR_INVALID_CONFIG);
+        TOSTR(VA_STATUS_ERROR_INVALID_CONTEXT);
+        TOSTR(VA_STATUS_ERROR_INVALID_SURFACE);
+        TOSTR(VA_STATUS_ERROR_INVALID_BUFFER);
+        TOSTR(VA_STATUS_ERROR_INVALID_IMAGE);
+        TOSTR(VA_STATUS_ERROR_INVALID_SUBPICTURE);
+        TOSTR(VA_STATUS_ERROR_ATTR_NOT_SUPPORTED);
+        TOSTR(VA_STATUS_ERROR_MAX_NUM_EXCEEDED);
+        TOSTR(VA_STATUS_ERROR_UNSUPPORTED_PROFILE);
+        TOSTR(VA_STATUS_ERROR_UNSUPPORTED_ENTRYPOINT);
+        TOSTR(VA_STATUS_ERROR_UNSUPPORTED_RT_FORMAT);
+        TOSTR(VA_STATUS_ERROR_UNSUPPORTED_BUFFERTYPE);
+        TOSTR(VA_STATUS_ERROR_SURFACE_BUSY);
+        TOSTR(VA_STATUS_ERROR_FLAG_NOT_SUPPORTED);
+        TOSTR(VA_STATUS_ERROR_INVALID_PARAMETER);
+        TOSTR(VA_STATUS_ERROR_RESOLUTION_NOT_SUPPORTED);
+        TOSTR(VA_STATUS_ERROR_UNIMPLEMENTED);
+        TOSTR(VA_STATUS_ERROR_SURFACE_IN_DISPLAYING);
+        TOSTR(VA_STATUS_ERROR_INVALID_IMAGE_FORMAT);
+        TOSTR(VA_STATUS_ERROR_DECODING_ERROR);
+        TOSTR(VA_STATUS_ERROR_ENCODING_ERROR);
+        TOSTR(VA_STATUS_ERROR_INVALID_VALUE);
+        TOSTR(VA_STATUS_ERROR_UNSUPPORTED_FILTER);
+        TOSTR(VA_STATUS_ERROR_INVALID_FILTER_CHAIN);
+        TOSTR(VA_STATUS_ERROR_HW_BUSY);
+        TOSTR(VA_STATUS_ERROR_UNSUPPORTED_MEMORY_TYPE);
+        TOSTR(VA_STATUS_ERROR_NOT_ENOUGH_BUFFER);
+        TOSTR(VA_STATUS_ERROR_UNKNOWN);
+        default: break;
+    }
+    return "unknown return value";
+}
+
 #undef TOSTR
